@@ -13,14 +13,14 @@ typedef Eo Efl_Io_Stderr;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Application's standard error (stderr).
- *
- * @since 1.19
  *
  * @ingroup Efl_Io_Stderr
  */
 #define EFL_IO_STDERR_CLASS efl_io_stderr_class_get()
 
 EWAPI const Efl_Class *efl_io_stderr_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
