@@ -13,15 +13,15 @@
 #endif
 
 #ifdef _WIN32
-# ifdef EFL_ECORE_FILE_BUILD
+# ifdef EFL_BUILD
 #  ifdef DLL_EXPORT
 #   define EAPI __declspec(dllexport)
 #  else
 #   define EAPI
-#  endif /* ! DLL_EXPORT */
+#  endif
 # else
 #  define EAPI __declspec(dllimport)
-# endif /* ! EFL_ECORE_FILE_BUILD */
+# endif
 #else
 # ifdef __GNUC__
 #  if __GNUC__ >= 4
@@ -32,7 +32,7 @@
 # else
 #  define EAPI
 # endif
-#endif /* ! _WIN32 */
+#endif
 
 /**
  * @file Ecore_File.h
@@ -195,7 +195,7 @@ EAPI Eina_Bool      ecore_file_is_dir       (const char *file);
  *
  * This function creates the directory @p dir, with the mode S_IRUSR |
  * S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH on UNIX
- * (mode is unsued on Windows). On success, it returns @c EINA_TRUE,
+ * (mode is unused on Windows). On success, it returns @c EINA_TRUE,
  * @c EINA_FALSE otherwise.
  */
 EAPI Eina_Bool      ecore_file_mkdir        (const char *dir);
@@ -319,9 +319,10 @@ EAPI Eina_Bool      ecore_file_mv           (const char *src, const char *dst);
  * @param  dest The name of link.
  * @return @c EINA_TRUE on success, @c EINA_FALSE otherwise.
  *
- * This function create the symbolic link @p dest of @p src. This
- * function does not work on Windows. It returns @c EINA_TRUE on success,
- * @c EINA_FALSE otherwise.
+ * This function creates the symbolic link @p dest of @p src. It returns
+ * @c EINA_TRUE on success, @c EINA_FALSE otherwise.
+ *
+ * @note On windows, this function always returns @c EINA_FALSE.
  */
 EAPI Eina_Bool      ecore_file_symlink      (const char *src, const char *dest);
 
@@ -378,12 +379,12 @@ EAPI const char    *ecore_file_file_get     (const char *path);
  * @param  file The name of the file.
  * @return The directory name.
  *
- * This function returns the directory where @p file resides as anewly
+ * This function returns the directory where @p file resides as newly
  * allocated string. If @p file is @c NULL or on error, this function
  * returns @c NULL. When not needed anymore, the returned value must
  * be freed.
  */
-EAPI char          *ecore_file_dir_get      (const char *path);
+EAPI char          *ecore_file_dir_get      (const char *file);
 
 /**
  * @brief Checks if the given file can be read.
@@ -422,13 +423,14 @@ EAPI Eina_Bool      ecore_file_can_exec     (const char *file);
 /**
  * @brief Gets the path pointed by the given link.
  *
- * @param  lnk The name of the link.
+ * @param  link The name of the link.
  * @return The path pointed by link or NULL.
  *
  * This function returns the path pointed by @p link as a newly
- * allocated string. This function does not work on Windows. On
- * failure, the function returns @c NULL. When not needed anymore, the
- * returned value must be freed.
+ * allocated string. On failure, the function returns @c NULL. When not
+ * needed anymore, the returned value must be freed.
+ *
+ * @note On windows, this function always returns @c NULL.
  */
 EAPI char          *ecore_file_readlink     (const char *link);
 
@@ -488,7 +490,7 @@ EAPI char          *ecore_file_escape_name  (const char *filename);
  * failure, the function returns @c NULL. When not needed anymore, the
  * returned value must be freed.
  */
-EAPI char          *ecore_file_strip_ext    (const char *file);
+EAPI char          *ecore_file_strip_ext    (const char *path);
 
 /**
  * @brief Checks if the given directory is empty.
@@ -535,9 +537,9 @@ EAPI Ecore_File_Monitor *ecore_file_monitor_add(const char *path,
  * monitored by ecore_file_monitor_add(). @p em must be the value
  * returned by ecore_file_monitor_add(). If @p em is @c NULL, or none
  * of the notify methods (Inotify, Windows notification or polling) is
- * availablethis function does nothing.
+ * available this function does nothing.
  */
-EAPI void                ecore_file_monitor_del(Ecore_File_Monitor *ecore_file_monitor);
+EAPI void                ecore_file_monitor_del(Ecore_File_Monitor *em);
 
 /**
  * @brief Gets the monitored path.
@@ -550,7 +552,7 @@ EAPI void                ecore_file_monitor_del(Ecore_File_Monitor *ecore_file_m
  * returned by ecore_file_monitor_add(). If @p em is @c NULL, the
  * function returns @c NULL.
  */
-EAPI const char         *ecore_file_monitor_path_get(Ecore_File_Monitor *ecore_file_monitor);
+EAPI const char         *ecore_file_monitor_path_get(Ecore_File_Monitor *em);
 
 /* Path */
 
@@ -663,7 +665,7 @@ EAPI void      ecore_file_download_abort_all(void);
 
 /**
  * @brief Aborts the given download job and call the completion_cb
- * callbck with a status of 1 (error).
+ * callback with a status of 1 (error).
  *
  * @param job The download job to abort.
  *
