@@ -13,6 +13,7 @@ typedef Eo Efl_Control;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl control interface
  *
  * @ingroup Efl_Control
@@ -24,6 +25,7 @@ EWAPI const Efl_Class *efl_control_interface_get(void);
 /**
  * @brief Control the priority of the object.
  *
+ * @param[in] obj The object.
  * @param[in] priority The priority of the object
  *
  * @ingroup Efl_Control
@@ -33,6 +35,8 @@ EOAPI void efl_control_priority_set(Eo *obj, int priority);
 /**
  * @brief Control the priority of the object.
  *
+ * @param[in] obj The object.
+ *
  * @return The priority of the object
  *
  * @ingroup Efl_Control
@@ -42,6 +46,7 @@ EOAPI int efl_control_priority_get(const Eo *obj);
 /**
  * @brief Controls whether the object is suspended or not.
  *
+ * @param[in] obj The object.
  * @param[in] suspend Controls whether the object is suspended or not.
  *
  * @ingroup Efl_Control
@@ -51,10 +56,13 @@ EOAPI void efl_control_suspend_set(Eo *obj, Eina_Bool suspend);
 /**
  * @brief Controls whether the object is suspended or not.
  *
+ * @param[in] obj The object.
+ *
  * @return Controls whether the object is suspended or not.
  *
  * @ingroup Efl_Control
  */
 EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
