@@ -11,9 +11,10 @@ typedef Eo Efl_Gfx_Buffer;
 #ifndef _EFL_GFX_BUFFER_EO_TYPES
 #define _EFL_GFX_BUFFER_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Graphics buffer access mode
  *
- * @ingroup Efl_Gfx_Buffer
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
@@ -23,9 +24,11 @@ typedef enum
   EFL_GFX_BUFFER_ACCESS_MODE_COW = 4 /**< Forces copy-on-write if already mapped
                                       * as read-only. Requires write. */
 } Efl_Gfx_Buffer_Access_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Common APIs for all objects representing images and 2D pixel buffers.
  *
  * @ingroup Efl_Gfx_Buffer
@@ -39,22 +42,23 @@ EWAPI const Efl_Class *efl_gfx_buffer_interface_get(void);
  *
  * Potentially not implemented, @ref efl_gfx_buffer_size_get may be read-only.
  *
- * @param[in] w Width in pixels.
- * @param[in] h Height in pixels.
+ * @param[in] obj The object.
+ * @param[in] sz Size of the buffer in pixels.
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI void efl_gfx_buffer_size_set(Eo *obj, int w, int h);
+EOAPI void efl_gfx_buffer_size_set(Eo *obj, Eina_Size2D sz);
 
 /**
  * @brief Rectangular size of the pixel buffer as allocated in memory.
  *
- * @param[out] w Width in pixels.
- * @param[out] h Height in pixels.
+ * @param[in] obj The object.
+ *
+ * @return Size of the buffer in pixels.
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI void efl_gfx_buffer_size_get(const Eo *obj, int *w, int *h);
+EOAPI Eina_Size2D efl_gfx_buffer_size_get(const Eo *obj);
 
 /**
  * @brief The colorspace defines how pixels are encoded in the image in memory.
@@ -70,6 +74,8 @@ EOAPI void efl_gfx_buffer_size_get(const Eo *obj, int *w, int *h);
  *
  * See @ref Efl_Gfx_Colorspace for more information on the supported formats.
  *
+ * @param[in] obj The object.
+ *
  * @return Colorspace
  *
  * @ingroup Efl_Gfx_Buffer
@@ -89,6 +95,7 @@ EOAPI Efl_Gfx_Colorspace efl_gfx_buffer_colorspace_get(const Eo *obj);
  * and @c false makes it ignore that data. Note that this has nothing to do
  * with an object's color as manipulated by @ref efl_gfx_color_set.
  *
+ * @param[in] obj The object.
  * @param[in] alpha Whether to use alpha channel ($true) data or not ($false).
  *
  * @ingroup Efl_Gfx_Buffer
@@ -103,6 +110,8 @@ EOAPI void efl_gfx_buffer_alpha_set(Eo *obj, Eina_Bool alpha);
  *
  * Retrieve whether alpha channel data is used on this object.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to use alpha channel ($true) data or not ($false).
  *
  * @ingroup Efl_Gfx_Buffer
@@ -118,6 +127,8 @@ EOAPI Eina_Bool efl_gfx_buffer_alpha_get(const Eo *obj);
  * When applicable, this will include the @ref efl_gfx_buffer_borders_get as
  * well as potential extra padding.
  *
+ * @param[in] obj The object.
+ *
  * @return Stride
  *
  * @ingroup Efl_Gfx_Buffer
@@ -130,14 +141,12 @@ EOAPI int efl_gfx_buffer_stride_get(const Eo *obj);
  * This function schedules a particular rectangular region of an image object
  * to be updated (redrawn) at the next rendering cycle.
  *
- * @param[in] x X-offset of the region to be updated.
- * @param[in] y Y-offset of the region to be updated.
- * @param[in] w Width of the region to be updated.
- * @param[in] h Height of the region to be updated.
+ * @param[in] obj The object.
+ * @param[in] region The updated region.
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI void efl_gfx_buffer_update_add(Eo *obj, int x, int y, int w, int h);
+EOAPI void efl_gfx_buffer_update_add(Eo *obj, const Eina_Rect *region);
 
 /**
  * @brief Duplicated pixel borders inside this buffer.
@@ -147,6 +156,7 @@ EOAPI void efl_gfx_buffer_update_add(Eo *obj, int x, int y, int w, int h);
  * borders to allow calling @ref efl_gfx_buffer_map with the entire pixel data,
  * including those edge pixels.
  *
+ * @param[in] obj The object.
  * @param[out] l Left border pixels, usually 0 or 1
  * @param[out] r Right border pixels, usually 0 or 1
  * @param[out] t Top border pixels, usually 0 or 1
@@ -166,24 +176,22 @@ EOAPI void efl_gfx_buffer_borders_get(const Eo *obj, unsigned int *l, unsigned i
  * Note that if the buffer has @ref efl_gfx_buffer_borders_get, then @c x and
  * @c y may be negative.
  *
- * @param[out] slice Pointer to the top-left pixel data.
+ * @param[in] obj The object.
  * @param[in] mode Specifies whether to map for read-only, write-only or
  * read-write access (OR combination of flags).
- * @param[in] x X position of the top-left pixel to map, defaults to 0.
- * @param[in] y Y position of the top-left pixel to map, defaults to 0.
- * @param[in] w If 0, defaults to the buffer width.
- * @param[in] h If 0, defaults to the buffer height.
+ * @param[in] region The region to map.
  * @param[in] cspace Requested colorspace. If different from the internal
  * cspace, map should try to convert the data into a new buffer. argb8888 by
  * default.
  * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
  * @param[out] stride Returns the length in bytes of a mapped line
  *
- * @return @c true on success, @c false otherwise
+ * @return The data slice. In case of failure, the memory pointer will be
+ * @c null.
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_map(Eo *obj, Eina_Rw_Slice *slice, Efl_Gfx_Buffer_Access_Mode mode, int x, int y, int w, int h, Efl_Gfx_Colorspace cspace, int plane, int *stride);
+EOAPI Eina_Rw_Slice efl_gfx_buffer_map(Eo *obj, Efl_Gfx_Buffer_Access_Mode mode, const Eina_Rect *region, Efl_Gfx_Colorspace cspace, int plane, int *stride);
 
 /**
  * @brief Unmap a region of this buffer, and update the internal data if
@@ -196,13 +204,14 @@ EOAPI Eina_Bool efl_gfx_buffer_map(Eo *obj, Eina_Rw_Slice *slice, Efl_Gfx_Buffer
  * after a call to @ref efl_gfx_buffer_unmap the original @c slice structure is
  * not valid anymore.
  *
+ * @param[in] obj The object.
  * @param[in] slice Data slice returned by a previous call to map.
  *
  * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, const Eina_Rw_Slice *slice);
+EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, Eina_Rw_Slice slice);
 
 /**
  * @brief Set the pixels for this buffer by copying them, or allocate a new
@@ -221,9 +230,9 @@ EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, const Eina_Rw_Slice *slice);
  *
  * @c slice should not be the return value of @ref efl_gfx_buffer_managed_get.
  *
+ * @param[in] obj The object.
  * @param[in] slice If @c null, allocates an empty buffer
- * @param[in] width Width
- * @param[in] height Height
+ * @param[in] size The size in pixels.
  * @param[in] stride If 0, automatically guessed from the @c width.
  * @param[in] cspace argb8888 by default.
  * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
@@ -232,7 +241,7 @@ EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, const Eina_Rw_Slice *slice);
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const Eina_Slice *slice, int width, int height, int stride, Efl_Gfx_Colorspace cspace, int plane);
+EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const Eina_Slice *slice, Eina_Size2D size, int stride, Efl_Gfx_Colorspace cspace, int plane);
 
 /**
  * @brief Set the pixels for this buffer, managed externally by the client.
@@ -250,9 +259,9 @@ EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const Eina_Slice *slice, int wi
  * See also @ref efl_gfx_buffer_copy_set if you want EFL to copy the input
  * buffer internally.
  *
+ * @param[in] obj The object.
  * @param[in] slice If @c null, detaches the previous buffer.
- * @param[in] width Width
- * @param[in] height Height
+ * @param[in] size The size in pixels.
  * @param[in] stride If 0, automatically guessed from the @c width.
  * @param[in] cspace argb8888 by default.
  * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
@@ -261,22 +270,23 @@ EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const Eina_Slice *slice, int wi
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_managed_set(Eo *obj, const Eina_Slice *slice, int width, int height, int stride, Efl_Gfx_Colorspace cspace, int plane);
+EOAPI Eina_Bool efl_gfx_buffer_managed_set(Eo *obj, const Eina_Slice *slice, Eina_Size2D size, int stride, Efl_Gfx_Colorspace cspace, int plane);
 
 /**
  * @brief Get a direct pointer to the internal pixel data, if available.
  *
  * This will return @c null unless @ref efl_gfx_buffer_managed_set was used to
- * pass in an external data pointer. The returned @ref Eina_Slice struct must
- * be freed by the caller.
+ * pass in an external data pointer.
  *
- * @param[out] slice Data slice
+ * @param[in] obj The object.
  * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
  *
- * @return @c true on success, @c false otherwise
+ * @return The data slice. The memory pointer will be @c null in case of
+ * failure.
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_managed_get(Eo *obj, Eina_Slice *slice, int plane);
+EOAPI Eina_Slice efl_gfx_buffer_managed_get(Eo *obj, int plane);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
