@@ -4,6 +4,7 @@
 #ifndef _EFL_GFX_TYPES_EOT_TYPES
 #define _EFL_GFX_TYPES_EOT_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Graphics colorspace type
  *
  * @ingroup Efl_Gfx
@@ -92,8 +93,11 @@ typedef enum
                                           *
                                           * @since 1.11. */
 } Efl_Gfx_Colorspace;
+#endif /* EFL_BETA_API_SUPPORT */
 
 /** Graphics render operation mode
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Gfx
  */
@@ -111,7 +115,7 @@ typedef enum
  *
  * @since 1.14
  *
- * @ingroup Efl_Gfx_Path
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
@@ -132,7 +136,7 @@ typedef enum
 } Efl_Gfx_Path_Command_Type;
 
 /** These values determine how the end of opened sub-paths are rendered in a
- * stroke. @c ref efl_gfx_shape_stroke_cap_set()
+ * stroke. @ref efl_gfx_shape_stroke_cap_set
  *
  * @since 1.14
  *
@@ -151,7 +155,7 @@ typedef enum
 } Efl_Gfx_Cap;
 
 /** These values determine how two joining lines are rendered in a stroker.
- * @c ref efl_gfx_shape_stroke_join_set()
+ * @ref efl_gfx_shape_stroke_join_set
  *
  * @since 1.14
  *
@@ -175,12 +179,12 @@ typedef enum
                      * iteration */
 } Efl_Gfx_Join;
 
-/** Specifies how the area outside the gradient area should be filled. @c ref
- * efl_gfx_gradient_spread_set()
+/** Specifies how the area outside the gradient area should be filled.
+ * @ref efl_gfx_gradient_spread_set
  *
  * @since 1.14
  *
- * @ingroup Efl_Gfx_Gradient
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
@@ -194,11 +198,12 @@ typedef enum
                                 * during iteration */
 } Efl_Gfx_Gradient_Spread;
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Type defining how an image content get filled.
  *
  * @since 1.14
  *
- * @ingroup Efl_Gfx_Fill
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
@@ -216,8 +221,9 @@ typedef enum
                                   * intersections is an odd number, the point
                                   * is inside the shape. */
 } Efl_Gfx_Fill_Rule;
+#endif /* EFL_BETA_API_SUPPORT */
 
-/** Type describing dash. @c ref efl_gfx_shape_stroke_dash_set()
+/** Type describing dash. @ref efl_gfx_shape_stroke_dash_set
  *
  * @since 1.14
  *
@@ -234,7 +240,7 @@ typedef struct _Efl_Gfx_Dash
  *
  * @since 1.14
  *
- * @ingroup Efl_Gfx_Gradient
+ * @ingroup Efl_Gfx
  */
 typedef struct _Efl_Gfx_Gradient_Stop
 {
@@ -246,9 +252,10 @@ typedef struct _Efl_Gfx_Gradient_Stop
   int a; /**< The component A color of the gradient stop */
 } Efl_Gfx_Gradient_Stop;
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Internal structure for @ref Efl_Gfx_Stroke.
  *
- * @ingroup Efl_Gfx_Stroke
+ * @ingroup Efl_Gfx
  */
 typedef struct _Efl_Gfx_Stroke_Color
 {
@@ -257,7 +264,9 @@ typedef struct _Efl_Gfx_Stroke_Color
   int b; /**< The component B color of the stroke */
   int a; /**< The component A color of the stroke */
 } Efl_Gfx_Stroke_Color;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Type defining stroke information. Describes the properties to define the
  * path stroke.
  *
@@ -275,51 +284,74 @@ typedef struct _Efl_Gfx_Stroke
   unsigned int dash_length; /**< Stroke dash length */
   Efl_Gfx_Cap cap; /**< Stroke cap */
   Efl_Gfx_Join join; /**< Stroke join */
+  double miterlimit; /**< Stroke miterlimit */
 } Efl_Gfx_Stroke;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Public shape
  *
- * @ingroup Efl_Gfx_Shape
+ * @ingroup Efl_Gfx
  */
 typedef struct _Efl_Gfx_Shape_Public
 {
   Efl_Gfx_Stroke stroke; /**< Internal representation as stroke */
 } Efl_Gfx_Shape_Public;
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+typedef enum
+{
+  EFL_GFX_VG_COMPOSITE_METHOD_NONE = 0,
+  EFL_GFX_VG_COMPOSITE_METHOD_MATTE_ALPHA,
+  EFL_GFX_VG_COMPOSITE_METHOD_MATTE_ALPHA_INVERSE,
+  EFL_GFX_VG_COMPOSITE_METHOD_MASK_ADD,
+  EFL_GFX_VG_COMPOSITE_METHOD_MASK_SUBSTRACT,
+  EFL_GFX_VG_COMPOSITE_METHOD_MASK_INTERSECT,
+  EFL_GFX_VG_COMPOSITE_METHOD_MASK_DIFFERENCE
+} Efl_Gfx_Vg_Composite_Method;
+#endif /* EFL_BETA_API_SUPPORT */
 
 /** How an image's center region (the complement to the border region) should
  * be rendered by EFL
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Gfx
  */
 typedef enum
 {
-  EFL_GFX_BORDER_FILL_MODE_NONE = 0, /**< Image's center region is @c b not to
-                                      * be rendered */
-  EFL_GFX_BORDER_FILL_MODE_DEFAULT = 1, /**< Image's center region is to be @c b
-                                         * blended with objects underneath it,
-                                         * if it has transparency. This is the
-                                         * default behavior for image objects
-                                         */
-  EFL_GFX_BORDER_FILL_MODE_SOLID = 2 /**< Image's center region is to be made
+  EFL_GFX_CENTER_FILL_MODE_NONE = 0, /**< Image's center region is @c not to be
+                                      * rendered */
+  EFL_GFX_CENTER_FILL_MODE_DEFAULT = 1, /**< Image's center region is to be
+                                         * @c blended with objects underneath
+                                         * it, if it has transparency. This is
+                                         * the default behavior for image
+                                         * objects */
+  EFL_GFX_CENTER_FILL_MODE_SOLID = 2 /**< Image's center region is to be made
                                       * solid, even if it has transparency on
                                       * it */
-} Efl_Gfx_Border_Fill_Mode;
+} Efl_Gfx_Center_Fill_Mode;
 
 /** What property got changed for this object
  *
  * @since 1.18
  *
- * @ingroup Efl_Gfx_Change
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
-  EFL_GFX_CHANGE_FLAG_NONE = 0, /**< No change */
-  EFL_GFX_CHANGE_FLAG_MATRIX = 1, /**< matrix got changed */
-  EFL_GFX_CHANGE_FLAG_PATH = 2, /**< path got changes */
-  EFL_GFX_CHANGE_FLAG_ALL = -1 /* +1 */ /**< all property got changed */
+  EFL_GFX_CHANGE_FLAG_NONE = 0, /**< Nothing changed. */
+  EFL_GFX_CHANGE_FLAG_MATRIX = 1, /**< Matrix got changed. */
+  EFL_GFX_CHANGE_FLAG_PATH = 2, /**< Path got changed. */
+  EFL_GFX_CHANGE_FLAG_FILL = 4, /**< Coloring or fill information changed, not
+                                 * geometry. */
+  EFL_GFX_CHANGE_FLAG_ALL = 65535 /**< All properties got changed. */
 } Efl_Gfx_Change_Flag;
 
 /** Data sent along a "render,post" event, after a frame has been rendered.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Gfx_Event
  */
@@ -332,63 +364,50 @@ typedef struct _Efl_Gfx_Event_Render_Post
 /**
  * @brief Aspect types/policies for scaling size hints.
  *
- * See also @c Efl.Gfx.Size.Hint.aspect.
+ * See also @ref efl_gfx_hint_aspect_get.
  *
- * @ingroup Efl_Gfx_Size_Hint
+ * @since 1.23
+ *
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
-  EFL_GFX_SIZE_HINT_ASPECT_NONE = 0, /**< No preference on either direction of
-                                      * the container for aspect ratio control.
-                                      */
-  EFL_GFX_SIZE_HINT_ASPECT_NEITHER = 1, /**< Same effect as disabling aspect
-                                         * ratio preference */
-  EFL_GFX_SIZE_HINT_ASPECT_HORIZONTAL = 2, /**< Use all horizontal container
-                                            * space to place an object, using
-                                            * the given aspect. */
-  EFL_GFX_SIZE_HINT_ASPECT_VERTICAL = 3, /**< Use all vertical container space
-                                          * to place an object, using the given
-                                          * aspect. */
-  EFL_GFX_SIZE_HINT_ASPECT_BOTH = 4 /**< Use all horizontal and vertical
-                                     * container spaces to place an object
-                                     * (never growing it out of those bounds),
-                                     * using the given aspect. */
-} Efl_Gfx_Size_Hint_Aspect;
+  EFL_GFX_HINT_ASPECT_NONE = 0, /**< No preference on either direction of the
+                                 * container for aspect ratio control. */
+  EFL_GFX_HINT_ASPECT_NEITHER = 1, /**< Same effect as disabling aspect ratio
+                                    * preference */
+  EFL_GFX_HINT_ASPECT_HORIZONTAL = 2, /**< Use all horizontal container space to
+                                       * place an object, using the given
+                                       * aspect. */
+  EFL_GFX_HINT_ASPECT_VERTICAL = 3, /**< Use all vertical container space to
+                                     * place an object, using the given aspect.
+                                     */
+  EFL_GFX_HINT_ASPECT_BOTH = 4 /**< Use all horizontal and vertical container
+                                * spaces to place an object (never growing it
+                                * out of those bounds), using the given aspect.
+                                */
+} Efl_Gfx_Hint_Aspect;
 
-/** Image or Edje load error type
+#ifdef EFL_BETA_API_SUPPORT
+/** Efl Gfx Color Class layer enum
  *
- * @ingroup Efl_Image_Load
+ * @ingroup Efl_Gfx
  */
 typedef enum
 {
-  EFL_IMAGE_LOAD_ERROR_NONE = 0, /**< No error on load */
-  EFL_IMAGE_LOAD_ERROR_GENERIC = 1, /**< A non-specific error occurred */
-  EFL_IMAGE_LOAD_ERROR_DOES_NOT_EXIST = 2, /**< File (or file path) does not
-                                            * exist */
-  EFL_IMAGE_LOAD_ERROR_PERMISSION_DENIED = 3, /**< Permission denied to an
-                                               * existing file (or path) */
-  EFL_IMAGE_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED = 4, /**< Allocation of
-                                                        * resources failure
-                                                        * prevented load */
-  EFL_IMAGE_LOAD_ERROR_CORRUPT_FILE = 5, /**< File corrupt (but was detected as
-                                          * a known format) */
-  EFL_IMAGE_LOAD_ERROR_UNKNOWN_FORMAT = 6, /**< File is not a known format */
-  EFL_IMAGE_LOAD_ERROR_CANCELLED = 7, /**< Reading operation has been cancelled
-                                       * during decoding */
-  EFL_IMAGE_LOAD_ERROR_INCOMPATIBLE_FILE = 8, /**< (Edje only) The file pointed
-                                               * to is incompatible, i.e., it
-                                               * doesn't match the library's
-                                               * current version's format. */
-  EFL_IMAGE_LOAD_ERROR_UNKNOWN_COLLECTION = 9, /**< (Edje only) The
-                                                * group/collection set to load
-                                                * from was not found in the
-                                                * file */
-  EFL_IMAGE_LOAD_ERROR_RECURSIVE_REFERENCE = 10 /**< (Edje only) The
-                                                 * group/collection set to load
-                                                 * from had recursive
-                                                 * references on its components
-                                                 */
-} Efl_Image_Load_Error;
+  EFL_GFX_COLOR_CLASS_LAYER_NORMAL = 0, /**< Default color */
+  EFL_GFX_COLOR_CLASS_LAYER_OUTLINE, /**< Outline color */
+  EFL_GFX_COLOR_CLASS_LAYER_SHADOW /**< Shadow color */
+} Efl_Gfx_Color_Class_Layer;
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/** Efl font size type
+ *
+ * @ingroup Efl_Font
+ */
+typedef int Efl_Font_Size;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
