@@ -61,7 +61,7 @@ EWAPI const Efl_Class *efl_io_manager_class_get(void);
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_ls(const Eo *obj, const char *path, void *paths_data, EflIoPath paths, Eina_Free_Cb paths_free_cb);
+EOAPI Eina_Future *efl_io_manager_ls(const Eo *obj, const char *path, void *paths_data, EflIoPath paths, Eina_Free_Cb paths_free_cb) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Lists entries in a given path with more information.
@@ -77,7 +77,7 @@ EOAPI Eina_Future *efl_io_manager_ls(const Eo *obj, const char *path, void *path
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_direct_ls(const Eo *obj, const char *path, Eina_Bool recursive, void *info_data, EflIoDirectInfo info, Eina_Free_Cb info_free_cb);
+EOAPI Eina_Future *efl_io_manager_direct_ls(const Eo *obj, const char *path, Eina_Bool recursive, void *info_data, EflIoDirectInfo info, Eina_Free_Cb info_free_cb) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Lists entries in a given path with stat information.
@@ -93,7 +93,7 @@ EOAPI Eina_Future *efl_io_manager_direct_ls(const Eo *obj, const char *path, Ein
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_stat_ls(const Eo *obj, const char *path, Eina_Bool recursive, void *info_data, EflIoDirectInfo info, Eina_Free_Cb info_free_cb);
+EOAPI Eina_Future *efl_io_manager_stat_ls(const Eo *obj, const char *path, Eina_Bool recursive, void *info_data, EflIoDirectInfo info, Eina_Free_Cb info_free_cb) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Lists all extended attributes asynchronously.
@@ -107,7 +107,7 @@ EOAPI Eina_Future *efl_io_manager_stat_ls(const Eo *obj, const char *path, Eina_
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_xattr_ls(const Eo *obj, const char *path, void *paths_data, EflIoPath paths, Eina_Free_Cb paths_free_cb);
+EOAPI Eina_Future *efl_io_manager_xattr_ls(const Eo *obj, const char *path, void *paths_data, EflIoPath paths, Eina_Free_Cb paths_free_cb) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Get stat info on a given file/directory.
@@ -134,7 +134,7 @@ EOAPI Eina_Future *efl_io_manager_stat(const Eo *obj, const char *path);
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_xattr_set(Eo *obj, const char *path, const char *attribute, Eina_Binbuf *data, Eina_Xattr_Flags flags);
+EOAPI Eina_Future *efl_io_manager_xattr_set(Eo *obj, const char *path, const char *attribute, Eina_Binbuf *data, Eina_Xattr_Flags flags) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Retrieves or sets information of a given extended attribute.
@@ -147,7 +147,7 @@ EOAPI Eina_Future *efl_io_manager_xattr_set(Eo *obj, const char *path, const cha
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_xattr_get(const Eo *obj, const char *path, const char *attribute);
+EOAPI Eina_Future *efl_io_manager_xattr_get(const Eo *obj, const char *path, const char *attribute) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Opens a file.
@@ -163,7 +163,7 @@ EOAPI Eina_Future *efl_io_manager_xattr_get(const Eo *obj, const char *path, con
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_open(const Eo *obj, const char *path, Eina_Bool shared);
+EOAPI Eina_Future *efl_io_manager_open(const Eo *obj, const char *path, Eina_Bool shared) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Closes an open Eina.File.
@@ -175,7 +175,7 @@ EOAPI Eina_Future *efl_io_manager_open(const Eo *obj, const char *path, Eina_Boo
  *
  * @ingroup Efl_Io_Manager
  */
-EOAPI Eina_Future *efl_io_manager_close(const Eo *obj, Eina_File *file);
+EOAPI Eina_Future *efl_io_manager_close(const Eo *obj, Eina_File *file) EFL_TRANSFER_OWNERSHIP;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
