@@ -11,6 +11,7 @@ typedef Eo Elm_Interface_Scrollable;
 #ifndef _ELM_INTERFACE_SCROLLABLE_EO_TYPES
 #define _ELM_INTERFACE_SCROLLABLE_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Type that controls when scrollbars should appear.
  *
@@ -20,13 +21,15 @@ typedef Eo Elm_Interface_Scrollable;
  */
 typedef enum
 {
-  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed */
-  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars */
-  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars */
-  ELM_SCROLLER_POLICY_LAST /**< Sentinel value to indicate last enum field
-                            * during iteration */
+  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed. */
+  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars. */
+  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars. */
+  ELM_SCROLLER_POLICY_LAST /**< Internal. Sentinel value to indicate last enum
+                            * field during iteration. */
 } Elm_Scroller_Policy;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Type that controls how the content is scrolled.
  *
@@ -36,32 +39,18 @@ typedef enum
  */
 typedef enum
 {
-  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction. */
   ELM_SCROLLER_SINGLE_DIRECTION_SOFT, /**< Scroll single direction if the
-                                       * direction is certain */
-  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction */
-  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Sentinel value to indicate last enum
-                                      * field during iteration */
+                                       * direction is certain. */
+  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction. */
+  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Internal. Sentinel value to indicate
+                                      * last enum field during iteration. */
 } Elm_Scroller_Single_Direction;
-
-/** Type that blocks the scroll movement in one or more direction.
- *
- * @since 1.8
- *
- * @ingroup Elm_Scroller
- */
-typedef enum
-{
-  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1 /* 1 >> 0 */, /**< Do not block movements
-                                                    */
-  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2 /* 1 >> 1 */, /**< Block vertical
-                                                          * movements */
-  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /* 1 >> 2 */ /**< Block horizontal
-                                                           * movements */
-} Elm_Scroller_Movement_Block;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elm scrollable mixin
  *
  * @ingroup Elm_Interface_Scrollable
@@ -79,12 +68,13 @@ EWAPI const Efl_Class *elm_interface_scrollable_mixin_get(void);
  * The scroller will adjust the view to glue itself as follows.
  *
  * x=0.0, for staying where it is relative to the left edge of the content
- * x=1.0, for staying where it is relative to the rigth edge of the content
+ * x=1.0, for staying where it is relative to the right edge of the content
  * y=0.0, for staying where it is relative to the top edge of the content
  * y=1.0, for staying where it is relative to the bottom edge of the content
  *
  * Default values for x and y are 0.0
  *
+ * @param[in] obj The object.
  * @param[in] x Horizontal scrolling gravity
  * @param[in] y Vertical scrolling gravity
  *
@@ -101,12 +91,13 @@ EOAPI void elm_interface_scrollable_gravity_set(Eo *obj, double x, double y);
  * The scroller will adjust the view to glue itself as follows.
  *
  * x=0.0, for staying where it is relative to the left edge of the content
- * x=1.0, for staying where it is relative to the rigth edge of the content
+ * x=1.0, for staying where it is relative to the right edge of the content
  * y=0.0, for staying where it is relative to the top edge of the content
  * y=1.0, for staying where it is relative to the bottom edge of the content
  *
  * Default values for x and y are 0.0
  *
+ * @param[in] obj The object.
  * @param[out] x Horizontal scrolling gravity
  * @param[out] y Vertical scrolling gravity
  *
@@ -122,6 +113,7 @@ EOAPI void elm_interface_scrollable_gravity_get(const Eo *obj, double *x, double
  * This is enabled by default for both axis. This API will set if it is enabled
  * for the given axis with the boolean parameters for each axis.
  *
+ * @param[in] obj The object.
  * @param[in] horiz Horizontal bounce policy.
  * @param[in] vert Vertical bounce policy.
  *
@@ -137,6 +129,7 @@ EOAPI void elm_interface_scrollable_bounce_allow_set(Eo *obj, Eina_Bool horiz, E
  * This is enabled by default for both axis. This API will set if it is enabled
  * for the given axis with the boolean parameters for each axis.
  *
+ * @param[in] obj The object.
  * @param[out] horiz Horizontal bounce policy.
  * @param[out] vert Vertical bounce policy.
  *
@@ -148,6 +141,7 @@ EOAPI void elm_interface_scrollable_bounce_allow_get(const Eo *obj, Eina_Bool *h
  * @brief Control Wheel disable Enable or disable mouse wheel to be used to
  * scroll the scroller content. heel is enabled by default.
  *
+ * @param[in] obj The object.
  * @param[in] disabled @c true if wheel is disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -158,6 +152,8 @@ EOAPI void elm_interface_scrollable_wheel_disabled_set(Eo *obj, Eina_Bool disabl
  * @brief Control Wheel disable Enable or disable mouse wheel to be used to
  * scroll the scroller content. heel is enabled by default.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if wheel is disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -169,46 +165,44 @@ EOAPI Eina_Bool elm_interface_scrollable_wheel_disabled_get(const Eo *obj);
  *
  * This function will block scrolling movement (by input of a user) in a given
  * direction. One can disable movements in the X axis, the Y axis or both. The
- * default value is #ELM_SCROLLER_MOVEMENT_NO_BLOCK, where movements are
- * allowed in both directions.
+ * default value is @c none, where movements are allowed in both directions.
  *
  * What makes this function different from freeze_push(), hold_push() and
  * lock_x_set() (or lock_y_set()) is that it doesn't propagate its effects to
  * any parent or child widget of @c obj. Only the target scrollable widget will
  * be locked with regard to scrolling.
  *
+ * @param[in] obj The object.
  * @param[in] block Which axis (or axes) to block
  *
- * @since 1.8
- *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Elm_Scroller_Movement_Block block);
+EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Efl_Ui_Layout_Orientation block);
 
 /**
  * @brief Blocking of scrolling (per axis)
  *
  * This function will block scrolling movement (by input of a user) in a given
  * direction. One can disable movements in the X axis, the Y axis or both. The
- * default value is #ELM_SCROLLER_MOVEMENT_NO_BLOCK, where movements are
- * allowed in both directions.
+ * default value is @c none, where movements are allowed in both directions.
  *
  * What makes this function different from freeze_push(), hold_push() and
  * lock_x_set() (or lock_y_set()) is that it doesn't propagate its effects to
  * any parent or child widget of @c obj. Only the target scrollable widget will
  * be locked with regard to scrolling.
  *
- * @return Which axis (or axes) to block
+ * @param[in] obj The object.
  *
- * @since 1.8
+ * @return Which axis (or axes) to block
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI Elm_Scroller_Movement_Block elm_interface_scrollable_movement_block_get(const Eo *obj);
+EOAPI Efl_Ui_Layout_Orientation elm_interface_scrollable_movement_block_get(const Eo *obj);
 
 /**
  * @brief Momentum animator
  *
+ * @param[in] obj The object.
  * @param[in] disabled @c true if disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -218,6 +212,8 @@ EOAPI void elm_interface_scrollable_momentum_animator_disabled_set(Eo *obj, Eina
 /**
  * @brief Momentum animator
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -227,11 +223,7 @@ EOAPI Eina_Bool elm_interface_scrollable_momentum_animator_disabled_get(const Eo
 /**
  * @brief Scrollbar visibility policy
  *
- * #ELM_SCROLLER_POLICY_AUTO means the scrollbar is made visible if it is
- * needed, and otherwise kept hidden. #ELM_SCROLLER_POLICY_ON turns it on all
- * the time, and #ELM_SCROLLER_POLICY_OFF always keeps it off. This applies
- * respectively for the horizontal and vertical scrollbars.
- *
+ * @param[in] obj The object.
  * @param[in] hbar Horizontal scrollbar policy
  * @param[in] vbar Vertical scrollbar policy
  *
@@ -242,11 +234,7 @@ EOAPI void elm_interface_scrollable_policy_set(Eo *obj, Elm_Scroller_Policy hbar
 /**
  * @brief Scrollbar visibility policy
  *
- * #ELM_SCROLLER_POLICY_AUTO means the scrollbar is made visible if it is
- * needed, and otherwise kept hidden. #ELM_SCROLLER_POLICY_ON turns it on all
- * the time, and #ELM_SCROLLER_POLICY_OFF always keeps it off. This applies
- * respectively for the horizontal and vertical scrollbars.
- *
+ * @param[in] obj The object.
  * @param[out] hbar Horizontal scrollbar policy
  * @param[out] vbar Vertical scrollbar policy
  *
@@ -265,6 +253,7 @@ EOAPI void elm_interface_scrollable_policy_get(const Eo *obj, Elm_Scroller_Polic
  *
  * See: @ref elm_interface_scrollable_content_region_show.
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate of the region
  * @param[in] y Y coordinate of the region
  * @param[in] w Width of the region
@@ -285,6 +274,7 @@ EOAPI void elm_interface_scrollable_content_region_set(Eo *obj, int x, int y, in
  *
  * See: @ref elm_interface_scrollable_content_region_show.
  *
+ * @param[in] obj The object.
  * @param[out] x X coordinate of the region
  * @param[out] y Y coordinate of the region
  * @param[out] w Width of the region
@@ -298,22 +288,25 @@ EOAPI void elm_interface_scrollable_content_region_get(const Eo *obj, int *x, in
  * @brief It decides whether the scrollable object propagates the events to
  * content object or not.
  *
+ * @param[in] obj The object.
  * @param[in] repeat_events @c true if events are propagated, @c false
  * otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_repeat_events_set(Eo *obj, Eina_Bool repeat_events);
+EOAPI void elm_interface_scrollable_content_events_set(Eo *obj, Eina_Bool repeat_events);
 
 /**
  * @brief It decides whether the scrollable object propagates the events to
  * content object or not.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if events are propagated, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI Eina_Bool elm_interface_scrollable_repeat_events_get(const Eo *obj);
+EOAPI Eina_Bool elm_interface_scrollable_content_events_get(const Eo *obj);
 
 /**
  * @brief Scroll page size relative to viewport size.
@@ -329,6 +322,7 @@ EOAPI Eina_Bool elm_interface_scrollable_repeat_events_get(const Eo *obj);
  * 1.0 including 1.0. If you only want 1 axis to be page "limited", use 0.0 for
  * the other axis.
  *
+ * @param[in] obj The object.
  * @param[in] x The horizontal page relative size
  * @param[in] y The vertical page relative size
  *
@@ -350,6 +344,7 @@ EOAPI void elm_interface_scrollable_page_size_set(Eo *obj, int x, int y);
  * 1.0 including 1.0. If you only want 1 axis to be page "limited", use 0.0 for
  * the other axis.
  *
+ * @param[in] obj The object.
  * @param[out] x The horizontal page relative size
  * @param[out] y The vertical page relative size
  *
@@ -360,6 +355,7 @@ EOAPI void elm_interface_scrollable_page_size_get(const Eo *obj, int *x, int *y)
 /**
  * @brief Bounce animator
  *
+ * @param[in] obj The object.
  * @param[in] disabled @c true if bounce animation is disabled, @c false
  * otherwise
  *
@@ -370,6 +366,8 @@ EOAPI void elm_interface_scrollable_bounce_animator_disabled_set(Eo *obj, Eina_B
 /**
  * @brief Bounce animator
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if bounce animation is disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -379,6 +377,7 @@ EOAPI Eina_Bool elm_interface_scrollable_bounce_animator_disabled_get(const Eo *
 /**
  * @brief Page scroll limit
  *
+ * @param[in] obj The object.
  * @param[in] page_limit_h Page limit horizontal
  * @param[in] page_limit_v Page limit vertical
  *
@@ -389,6 +388,7 @@ EOAPI void elm_interface_scrollable_page_scroll_limit_set(Eo *obj, int page_limi
 /**
  * @brief Page scroll limit
  *
+ * @param[in] obj The object.
  * @param[out] page_limit_h Page limit horizontal
  * @param[out] page_limit_v Page limit vertical
  *
@@ -408,11 +408,10 @@ EOAPI void elm_interface_scrollable_page_scroll_limit_get(const Eo *obj, int *pa
  * @note If @c obj is not set to have pages, nothing will happen after this
  * call.
  *
+ * @param[in] obj The object.
  * @param[in] horiz Allow snap horizontally
  * @param[in] vert Allow snap vertically
  *
- * @since 1.8
- *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_page_snap_allow_set(Eo *obj, Eina_Bool horiz, Eina_Bool vert);
@@ -429,18 +428,18 @@ EOAPI void elm_interface_scrollable_page_snap_allow_set(Eo *obj, Eina_Bool horiz
  * @note If @c obj is not set to have pages, nothing will happen after this
  * call.
  *
+ * @param[in] obj The object.
  * @param[out] horiz Allow snap horizontally
  * @param[out] vert Allow snap vertically
  *
- * @since 1.8
- *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_page_snap_allow_get(const Eo *obj, Eina_Bool *horiz, Eina_Bool *vert);
 
 /**
- * @brief Pagin property
+ * @brief Paging property
  *
+ * @param[in] obj The object.
  * @param[in] pagerel_h Page relation horizontal
  * @param[in] pagerel_v Page relation vertical
  * @param[in] pagesize_h Page size horizontal
@@ -451,8 +450,9 @@ EOAPI void elm_interface_scrollable_page_snap_allow_get(const Eo *obj, Eina_Bool
 EOAPI void elm_interface_scrollable_paging_set(Eo *obj, double pagerel_h, double pagerel_v, int pagesize_h, int pagesize_v);
 
 /**
- * @brief Pagin property
+ * @brief Paging property
  *
+ * @param[in] obj The object.
  * @param[out] pagerel_h Page relation horizontal
  * @param[out] pagerel_v Page relation vertical
  * @param[out] pagesize_h Page size horizontal
@@ -474,10 +474,9 @@ EOAPI void elm_interface_scrollable_paging_get(const Eo *obj, double *pagerel_h,
  * only move according to it while if the move was clearly wanted on both axes,
  * it will happen on both of them.
  *
+ * @param[in] obj The object.
  * @param[in] single_dir The single direction scroll policy
  *
- * @since 1.8
- *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_single_direction_set(Eo *obj, Elm_Scroller_Single_Direction single_dir);
@@ -494,9 +493,9 @@ EOAPI void elm_interface_scrollable_single_direction_set(Eo *obj, Elm_Scroller_S
  * only move according to it while if the move was clearly wanted on both axes,
  * it will happen on both of them.
  *
- * @return The single direction scroll policy
+ * @param[in] obj The object.
  *
- * @since 1.8
+ * @return The single direction scroll policy
  *
  * @ingroup Elm_Interface_Scrollable
  */
@@ -505,6 +504,7 @@ EOAPI Elm_Scroller_Single_Direction elm_interface_scrollable_single_direction_ge
 /**
  * @brief Step size
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate
  * @param[in] y Y coordinate
  *
@@ -515,6 +515,7 @@ EOAPI void elm_interface_scrollable_step_size_set(Eo *obj, int x, int y);
 /**
  * @brief Step size
  *
+ * @param[in] obj The object.
  * @param[out] x X coordinate
  * @param[out] y Y coordinate
  *
@@ -525,30 +526,29 @@ EOAPI void elm_interface_scrollable_step_size_get(const Eo *obj, int *x, int *y)
 /**
  * @brief Controls an infinite loop for a scroller.
  *
+ * @param[in] obj The object.
  * @param[in] loop_h The scrolling horizontal loop
  * @param[in] loop_v The scrolling vertical loop
  *
- * @since 1.14
- *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_loop_set(Eo *obj, Eina_Bool loop_h, Eina_Bool loop_v);
+EOAPI void elm_interface_scrollable_content_loop_set(Eo *obj, Eina_Bool loop_h, Eina_Bool loop_v);
 
 /**
  * @brief Controls an infinite loop for a scroller.
  *
+ * @param[in] obj The object.
  * @param[out] loop_h The scrolling horizontal loop
  * @param[out] loop_v The scrolling vertical loop
  *
- * @since 1.14
- *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_loop_get(const Eo *obj, Eina_Bool *loop_h, Eina_Bool *loop_v);
+EOAPI void elm_interface_scrollable_content_loop_get(const Eo *obj, Eina_Bool *loop_h, Eina_Bool *loop_v);
 
 /**
  * @brief Set the callback to run when the content has been moved up.
  *
+ * @param[in] obj The object.
  * @param[in] scroll_up_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -558,6 +558,7 @@ EOAPI void elm_interface_scrollable_scroll_up_cb_set(Eo *obj, Elm_Interface_Scro
 /**
  * @brief Set the callback to run when the horizontal scrollbar is dragged.
  *
+ * @param[in] obj The object.
  * @param[in] hbar_drag_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -567,6 +568,7 @@ EOAPI void elm_interface_scrollable_hbar_drag_cb_set(Eo *obj, Elm_Interface_Scro
 /**
  * @brief Set the callback to run when dragging of the contents has started.
  *
+ * @param[in] obj The object.
  * @param[in] drag_start_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -576,6 +578,7 @@ EOAPI void elm_interface_scrollable_drag_start_cb_set(Eo *obj, Elm_Interface_Scr
 /**
  * @brief Freeze property
  *
+ * @param[in] obj The object.
  * @param[in] freeze @c true if freeze, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -585,6 +588,7 @@ EOAPI void elm_interface_scrollable_freeze_set(Eo *obj, Eina_Bool freeze);
 /**
  * @brief When the viewport is resized, the callback is called.
  *
+ * @param[in] obj The object.
  * @param[in] viewport_resize_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -594,6 +598,7 @@ EOAPI void elm_interface_scrollable_content_viewport_resize_cb_set(Eo *obj, Elm_
 /**
  * @brief Set the callback to run when the content has been moved to the left
  *
+ * @param[in] obj The object.
  * @param[in] scroll_left_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -603,6 +608,7 @@ EOAPI void elm_interface_scrollable_scroll_left_cb_set(Eo *obj, Elm_Interface_Sc
 /**
  * @brief Set the callback to run when the vertical scrollbar is pressed.
  *
+ * @param[in] obj The object.
  * @param[in] vbar_press_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -612,6 +618,7 @@ EOAPI void elm_interface_scrollable_vbar_press_cb_set(Eo *obj, Elm_Interface_Scr
 /**
  * @brief Set the callback to run when the horizontal scrollbar is pressed.
  *
+ * @param[in] obj The object.
  * @param[in] hbar_press_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -621,6 +628,7 @@ EOAPI void elm_interface_scrollable_hbar_press_cb_set(Eo *obj, Elm_Interface_Scr
 /**
  * @brief Set the callback to run when the horizontal scrollbar is unpressed.
  *
+ * @param[in] obj The object.
  * @param[in] hbar_unpress_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -630,6 +638,7 @@ EOAPI void elm_interface_scrollable_hbar_unpress_cb_set(Eo *obj, Elm_Interface_S
 /**
  * @brief Set the callback to run when dragging of the contents has stopped.
  *
+ * @param[in] obj The object.
  * @param[in] drag_stop_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -639,6 +648,7 @@ EOAPI void elm_interface_scrollable_drag_stop_cb_set(Eo *obj, Elm_Interface_Scro
 /**
  * @brief Extern pan
  *
+ * @param[in] obj The object.
  * @param[in] pan Pan object
  *
  * @ingroup Elm_Interface_Scrollable
@@ -648,6 +658,7 @@ EOAPI void elm_interface_scrollable_extern_pan_set(Eo *obj, Efl_Canvas_Object *p
 /**
  * @brief Set the callback to run when the visible page changes.
  *
+ * @param[in] obj The object.
  * @param[in] page_change_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -657,6 +668,7 @@ EOAPI void elm_interface_scrollable_page_change_cb_set(Eo *obj, Elm_Interface_Sc
 /**
  * @brief Hold property
  *
+ * @param[in] obj The object.
  * @param[in] hold @c true if hold, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
@@ -666,6 +678,7 @@ EOAPI void elm_interface_scrollable_hold_set(Eo *obj, Eina_Bool hold);
 /**
  * @brief Set the callback to run when the scrolling animation has started.
  *
+ * @param[in] obj The object.
  * @param[in] animate_start_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -675,6 +688,7 @@ EOAPI void elm_interface_scrollable_animate_start_cb_set(Eo *obj, Elm_Interface_
 /**
  * @brief Set the callback to run when the content has been moved down.
  *
+ * @param[in] obj The object.
  * @param[in] scroll_down_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -684,6 +698,7 @@ EOAPI void elm_interface_scrollable_scroll_down_cb_set(Eo *obj, Elm_Interface_Sc
 /**
  * @brief Set scroll page size relative to viewport size.
  *
+ * @param[in] obj The object.
  * @param[in] h_pagerel Page relation horizontal
  * @param[in] v_pagerel Page relation vertical
  *
@@ -694,6 +709,7 @@ EOAPI void elm_interface_scrollable_page_relative_set(Eo *obj, double h_pagerel,
 /**
  * @brief Set the callback to run when the content has been moved.
  *
+ * @param[in] obj The object.
  * @param[in] scroll_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -703,24 +719,17 @@ EOAPI void elm_interface_scrollable_scroll_cb_set(Eo *obj, Elm_Interface_Scrolla
 /**
  * @brief Set the callback to run when the scrolling animation has stopped.
  *
+ * @param[in] obj The object.
  * @param[in] animate_stop_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_animate_stop_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb animate_stop_cb);
 
-/**
- * @brief Mirroed property
- *
- * @param[in] mirrored @c true if mirrored, @c false otherwise
- *
- * @ingroup Elm_Interface_Scrollable
- */
-EOAPI void elm_interface_scrollable_mirrored_set(Eo *obj, Eina_Bool mirrored);
-
 /**
  * @brief set the callback to run on minimal limit content
  *
+ * @param[in] obj The object.
  * @param[in] min_limit_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -730,6 +739,7 @@ EOAPI void elm_interface_scrollable_content_min_limit_cb_set(Eo *obj, Elm_Interf
 /**
  * @brief Set the callback to run when the content has been moved to the right.
  *
+ * @param[in] obj The object.
  * @param[in] scroll_right_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -739,6 +749,7 @@ EOAPI void elm_interface_scrollable_scroll_right_cb_set(Eo *obj, Elm_Interface_S
 /**
  * @brief Content property
  *
+ * @param[in] obj The object.
  * @param[in] content Content object
  *
  * @ingroup Elm_Interface_Scrollable
@@ -749,6 +760,7 @@ EOAPI void elm_interface_scrollable_content_set(Eo *obj, Efl_Canvas_Object *cont
  * @brief Set the callback to run when the left edge of the content has been
  * reached.
  *
+ * @param[in] obj The object.
  * @param[in] edge_left_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -758,6 +770,7 @@ EOAPI void elm_interface_scrollable_edge_left_cb_set(Eo *obj, Elm_Interface_Scro
 /**
  * @brief Set the callback to run when the horizontal scrollbar is dragged.
  *
+ * @param[in] obj The object.
  * @param[in] vbar_drag_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -767,6 +780,7 @@ EOAPI void elm_interface_scrollable_vbar_drag_cb_set(Eo *obj, Elm_Interface_Scro
 /**
  * @brief Set the callback to run when the horizontal scrollbar is unpressed.
  *
+ * @param[in] obj The object.
  * @param[in] vbar_unpress_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -777,6 +791,7 @@ EOAPI void elm_interface_scrollable_vbar_unpress_cb_set(Eo *obj, Elm_Interface_S
  * @brief Set the callback to run when the bottom edge of the content has been
  * reached.
  *
+ * @param[in] obj The object.
  * @param[in] edge_bottom_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -787,6 +802,7 @@ EOAPI void elm_interface_scrollable_edge_bottom_cb_set(Eo *obj, Elm_Interface_Sc
  * @brief Set the callback to run when the right edge of the content has been
  * reached.
  *
+ * @param[in] obj The object.
  * @param[in] edge_right_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -797,6 +813,7 @@ EOAPI void elm_interface_scrollable_edge_right_cb_set(Eo *obj, Elm_Interface_Scr
  * @brief Set the callback to run when the top edge of the content has been
  * reached.
  *
+ * @param[in] obj The object.
  * @param[in] edge_top_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
@@ -806,6 +823,7 @@ EOAPI void elm_interface_scrollable_edge_top_cb_set(Eo *obj, Elm_Interface_Scrol
 /**
  * @brief Object property
  *
+ * @param[in] obj The object.
  * @param[in] edje_object Edje object
  * @param[in] hit_rectangle Evas object
  *
@@ -814,7 +832,7 @@ EOAPI void elm_interface_scrollable_edge_top_cb_set(Eo *obj, Elm_Interface_Scrol
 EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje_object, Efl_Canvas_Object *hit_rectangle);
 
 /**
- * @brief Get scroll last page number.
+ * @brief Scroll last page number.
  *
  * The page number starts from 0. 0 is the first page. This returns the last
  * page number among the pages.
@@ -823,6 +841,7 @@ EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje
  * @ref elm_interface_scrollable_page_show and
  * @ref elm_interface_scrollable_page_bring_in.
  *
+ * @param[in] obj The object.
  * @param[out] pagenumber_h The horizontal page number
  * @param[out] pagenumber_v The vertical page number
  *
@@ -831,7 +850,7 @@ EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje
 EOAPI void elm_interface_scrollable_last_page_get(const Eo *obj, int *pagenumber_h, int *pagenumber_v);
 
 /**
- * @brief Get scroll current page number.
+ * @brief Scroll current page number.
  *
  * The page number starts from 0. 0 is the first page. Current page means the
  * page which meets the top-left of the viewport. If there are two or more
@@ -842,6 +861,7 @@ EOAPI void elm_interface_scrollable_last_page_get(const Eo *obj, int *pagenumber
  * @ref elm_interface_scrollable_page_show and
  * @ref elm_interface_scrollable_page_bring_in.
  *
+ * @param[in] obj The object.
  * @param[out] pagenumber_h The horizontal page number
  * @param[out] pagenumber_v The vertical page number
  *
@@ -852,6 +872,7 @@ EOAPI void elm_interface_scrollable_current_page_get(const Eo *obj, int *pagenum
 /**
  * @brief Content viewport geometry
  *
+ * @param[in] obj The object.
  * @param[out] x X coordinate
  * @param[out] y Y coordinate
  * @param[out] w Width
@@ -866,6 +887,7 @@ EOAPI void elm_interface_scrollable_content_viewport_geometry_get(const Eo *obj,
  *
  * This gets the size of the content object of the scroller.
  *
+ * @param[in] obj The object.
  * @param[out] w Width of the content object.
  * @param[out] h Height of the content object.
  *
@@ -876,6 +898,7 @@ EOAPI void elm_interface_scrollable_content_size_get(const Eo *obj, int *w, int
 /**
  * @brief Set the content position
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate
  * @param[in] y Y coordinate
  * @param[in] sig Send signals to the theme corresponding to the scroll
@@ -888,12 +911,13 @@ EOAPI void elm_interface_scrollable_content_pos_set(Eo *obj, int x, int y, Eina_
 /**
  * @brief Get content position
  *
+ * @param[in] obj The object.
  * @param[out] x X coordinate
  * @param[out] y Y coordinate
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_content_pos_get(Eo *obj, int *x, int *y);
+EOAPI void elm_interface_scrollable_content_pos_get(const Eo *obj, int *x, int *y);
 
 /**
  * @brief Show a specific virtual region within the scroller content object by
@@ -904,6 +928,7 @@ EOAPI void elm_interface_scrollable_content_pos_get(Eo *obj, int *x, int *y);
  *
  * See @ref elm_interface_scrollable_page_bring_in.
  *
+ * @param[in] obj The object.
  * @param[in] pagenumber_h The horizontal page number
  * @param[in] pagenumber_v The vertical page number
  *
@@ -924,6 +949,7 @@ EOAPI void elm_interface_scrollable_page_show(Eo *obj, int pagenumber_h, int pag
  *
  * See @ref elm_interface_scrollable_content_region_show
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate of the region
  * @param[in] y Y coordinate of the region
  * @param[in] w Width of the region
@@ -942,6 +968,7 @@ EOAPI void elm_interface_scrollable_region_bring_in(Eo *obj, int x, int y, int w
  *
  * @ref elm_interface_scrollable_page_show
  *
+ * @param[in] obj The object.
  * @param[in] pagenumber_h The horizontal page number
  * @param[in] pagenumber_v The vertical page number
  *
@@ -956,6 +983,7 @@ EOAPI void elm_interface_scrollable_page_bring_in(Eo *obj, int pagenumber_h, int
  * in the virtual content object (0, 0 starting at the top-left of the virtual
  * content object) is shown within the scroller.
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate of the region
  * @param[in] y Y coordinate of the region
  * @param[in] w Width of the region
@@ -974,6 +1002,7 @@ EOAPI void elm_interface_scrollable_content_region_show(Eo *obj, int x, int y, i
  * horizontally and/or vertically to perfectly fit its content in that
  * direction.
  *
+ * @param[in] obj The object.
  * @param[in] w Whether to limit the minimum horizontal size
  * @param[in] h Whether to limit the minimum vertical size
  *
@@ -981,6 +1010,27 @@ EOAPI void elm_interface_scrollable_content_region_show(Eo *obj, int x, int y, i
  */
 EOAPI void elm_interface_scrollable_content_min_limit(Eo *obj, Eina_Bool w, Eina_Bool h);
 
+/**
+ * @brief Whether scrolling should loop around.
+ *
+ * @param[in] obj The object.
+ * @param[in] enable True to enable looping.
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_item_loop_enabled_set(Eo *obj, Eina_Bool enable);
+
+/**
+ * @brief Whether scrolling should loop around.
+ *
+ * @param[in] obj The object.
+ *
+ * @return True to enable looping.
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI Eina_Bool elm_interface_scrollable_item_loop_enabled_get(const Eo *obj);
+
 EWAPI extern const Efl_Event_Description _ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED;
 
 /** Called when content changed
@@ -988,5 +1038,6 @@ EWAPI extern const Efl_Event_Description _ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED
  * @ingroup Elm_Interface_Scrollable
  */
 #define ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED (&(_ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
