@@ -20,6 +20,8 @@ typedef struct _Efl_Canvas_Object_Animation_Event Efl_Canvas_Object_Animation_Ev
 #endif /* EFL_BETA_API_SUPPORT */
 
 /** EFL event animator tick data structure
+ *
+ * @since 1.22
  *
  * @ingroup Efl
  */
@@ -95,8 +97,7 @@ EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get
  * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
  * be emitted just when inside this object area.
  *
- * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
- * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * See also: @ref efl_canvas_object_pointer_mode_by_device_get and
  * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
  * only set/get the mode for the default pointer.
  *
@@ -127,8 +128,7 @@ EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Poi
  * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
  * be emitted just when inside this object area.
  *
- * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
- * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * See also: @ref efl_canvas_object_pointer_mode_by_device_get and
  * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
  * only set/get the mode for the default pointer.
  *
@@ -154,7 +154,7 @@ EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo
  * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
  * "poke" holes in a window (to see through it), as only the compositor can
  * ensure that. Copy mode should only be used with otherwise opaque widgets or
- * inside non-window surfaces (eg. a transparent background inside a buffer
+ * inside non-window surfaces (e.g. a transparent background inside a buffer
  * canvas).
  *
  * @param[in] obj The object.
@@ -177,7 +177,7 @@ EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op)
  * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
  * "poke" holes in a window (to see through it), as only the compositor can
  * ensure that. Copy mode should only be used with otherwise opaque widgets or
- * inside non-window surfaces (eg. a transparent background inside a buffer
+ * inside non-window surfaces (e.g. a transparent background inside a buffer
  * canvas).
  *
  * @param[in] obj The object.
@@ -193,7 +193,7 @@ EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
 /**
  * @brief Clip one object to another.
  *
- * This function will clip the object @c obj to the area occupied by the object
+ * This property will clip the object @c obj to the area occupied by the object
  * @c clip. This means the object @c obj will only be visible within the area
  * occupied by the clipping object ($clip).
  *
@@ -234,14 +234,44 @@ EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper) EINA_ARG_NONNULL(2);
+EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper);
 
 /**
- * @brief Get the object clipping @c obj (if any).
+ * @brief Clip one object to another.
  *
- * This function returns the object clipping @c obj. If @c obj is not being
- * clipped at all, @c null is returned. The object @c obj must be a valid
- * Evas_Object.
+ * This property will clip the object @c obj to the area occupied by the object
+ * @c clip. This means the object @c obj will only be visible within the area
+ * occupied by the clipping object ($clip).
+ *
+ * The color of the object being clipped will be multiplied by the color of the
+ * clipping one, so the resulting color for the former will be "RESULT = (OBJ *
+ * CLIP) / (255 * 255)", per color element (red, green, blue and alpha).
+ *
+ * Clipping is recursive, so clipping objects may be clipped by others, and
+ * their color will in term be multiplied. You may not set up circular clipping
+ * lists (i.e. object 1 clips object 2, which clips object 1): the behavior of
+ * Evas is undefined in this case.
+ *
+ * Objects which do not clip others are visible in the canvas as normal; those
+ * that clip one or more objects become invisible themselves, only affecting
+ * what they clip. If an object ceases to have other objects being clipped by
+ * it, it will become visible again.
+ *
+ * The visibility of an object affects the objects that are clipped by it, so
+ * if the object clipping others is not shown (as in
+ * @ref efl_gfx_entity_visible_get), the objects clipped by it will not be
+ * shown  either.
+ *
+ * If @c obj was being clipped by another object when this function is  called,
+ * it gets implicitly removed from the old clipper's domain and is made now to
+ * be clipped by its new clipper.
+ *
+ * If @c clip is @c null, this call will disable clipping for the object i.e.
+ * its visibility and color get detached from the previous clipper. If it
+ * wasn't, this has no effect.
+ *
+ * @note Only rectangle and image (masks) objects can be used as clippers.
+ * Anything else will result in undefined behaviour.
  *
  * @param[in] obj The object.
  *
@@ -253,8 +283,47 @@ EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper) EI
  */
 EOAPI Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set whether an Evas object is to repeat events.
+ * @brief A hint for an object that its size will not change.
+ *
+ * When this flag is set, various optimizations may be employed by the renderer
+ * based on the fixed size of the object.
+ *
+ * It is a user error to change the size of an object while this flag is set.
+ *
+ * @param[in] obj The object.
+ * @param[in] enable Whether the object size is known to be static.
+ *
+ * @since 1.23
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI void efl_canvas_object_has_fixed_size_set(Eo *obj, Eina_Bool enable);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief A hint for an object that its size will not change.
+ *
+ * When this flag is set, various optimizations may be employed by the renderer
+ * based on the fixed size of the object.
+ *
+ * It is a user error to change the size of an object while this flag is set.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether the object size is known to be static.
+ *
+ * @since 1.23
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_has_fixed_size_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
+
+/**
+ * @brief Whether an Evas object is to repeat events to objects below it.
  *
  * If @c repeat is @c true, it will make events on @c obj to also be repeated
  * for the next lower object in the objects' stack (see see
@@ -274,7 +343,14 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
 EOAPI void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
 
 /**
- * @brief Determine whether an object is set to repeat events.
+ * @brief Whether an Evas object is to repeat events to objects below it.
+ *
+ * If @c repeat is @c true, it will make events on @c obj to also be repeated
+ * for the next lower object in the objects' stack (see see
+ * @ref efl_gfx_stack_below_get).
+ *
+ * If @c repeat is @c false, events occurring on @c obj will be processed only
+ * on it.
  *
  * @param[in] obj The object.
  *
@@ -403,10 +479,10 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief Set whether to use precise (usually expensive) point collision
- * detection for a given Evas object.
+ * @brief Whether to use precise (usually expensive) point collision detection
+ * for a given Evas object.
  *
- * Use this function to make Evas treat objects' transparent areas as not
+ * Use this property to make Evas treat objects' transparent areas as not
  * belonging to it with regard to mouse pointer events. By default, all of the
  * object's boundary rectangle will be taken in account for them.
  *
@@ -414,8 +490,7 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat
  * more resource intensive.
  *
  * @param[in] obj The object.
- * @param[in] precise Whether to use precise point collision detection or not.
- * The default value is false.
+ * @param[in] precise Whether to use precise point collision detection.
  *
  * @since 1.22
  *
@@ -424,13 +499,19 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat
 EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
 
 /**
- * @brief Determine whether an object is set to use precise point collision
- * detection.
+ * @brief Whether to use precise (usually expensive) point collision detection
+ * for a given Evas object.
+ *
+ * Use this property to make Evas treat objects' transparent areas as not
+ * belonging to it with regard to mouse pointer events. By default, all of the
+ * object's boundary rectangle will be taken in account for them.
+ *
+ * @warning By using precise point collision detection you'll be making Evas
+ * more resource intensive.
  *
  * @param[in] obj The object.
  *
- * @return Whether to use precise point collision detection or not. The default
- * value is false.
+ * @return Whether to use precise point collision detection.
  *
  * @since 1.22
  *
@@ -439,21 +520,21 @@ EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
 EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
 
 /**
- * @brief Set whether events on a smart object's member should be propagated up
- * to its parent.
+ * @brief Whether events on a smart object's member should be propagated up to
+ * its parent.
  *
  * This function has no effect if @c obj is not a member of a smart object.
  *
  * If @c prop is @c true, events occurring on this object will be propagated on
  * to the smart object of which @c obj is a member. If @c prop is @c false,
  * events occurring on this object will not be propagated on to the smart
- * object of which @c obj is a member. The default value is @c true.
+ * object of which @c obj is a member.
  *
  * See also @ref efl_canvas_object_repeat_events_set,
  * @ref efl_canvas_object_pass_events_set.
  *
  * @param[in] obj The object.
- * @param[in] propagate Whether to propagate events ($true) or not ($false).
+ * @param[in] propagate Whether to propagate events.
  *
  * @since 1.22
  *
@@ -462,14 +543,22 @@ EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
 EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
 
 /**
- * @brief Retrieve whether an Evas object is set to propagate events.
+ * @brief Whether events on a smart object's member should be propagated up to
+ * its parent.
  *
- * See also @ref efl_canvas_object_repeat_events_get,
- * @ref efl_canvas_object_pass_events_get.
+ * This function has no effect if @c obj is not a member of a smart object.
+ *
+ * If @c prop is @c true, events occurring on this object will be propagated on
+ * to the smart object of which @c obj is a member. If @c prop is @c false,
+ * events occurring on this object will not be propagated on to the smart
+ * object of which @c obj is a member.
+ *
+ * See also @ref efl_canvas_object_repeat_events_set,
+ * @ref efl_canvas_object_pass_events_set.
  *
  * @param[in] obj The object.
  *
- * @return Whether to propagate events ($true) or not ($false).
+ * @return Whether to propagate events.
  *
  * @since 1.22
  *
@@ -478,7 +567,7 @@ EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
 EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
 
 /**
- * @brief Set whether an Evas object is to pass (ignore) events.
+ * @brief Whether an Evas object is to pass (ignore) events.
  *
  * If @c pass is @c true, it will make events on @c obj to be ignored. They
  * will be triggered on the next lower object (that is not set to pass events),
@@ -499,10 +588,16 @@ EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
 EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
 
 /**
- * @brief Determine whether an object is set to pass (ignore) events.
+ * @brief Whether an Evas object is to pass (ignore) events.
  *
- * See also @ref efl_canvas_object_repeat_events_get,
- * @ref efl_canvas_object_propagate_events_get.
+ * If @c pass is @c true, it will make events on @c obj to be ignored. They
+ * will be triggered on the next lower object (that is not set to pass events),
+ * instead (see @ref efl_gfx_stack_below_get).
+ *
+ * If @c pass is @c false events will be processed on that object as normal.
+ *
+ * See also @ref efl_canvas_object_repeat_events_set,
+ * @ref efl_canvas_object_propagate_events_set
  *
  * @param[in] obj The object.
  *
@@ -515,8 +610,7 @@ EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
 EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
 
 /**
- * @brief Sets whether or not the given Evas object is to be drawn
- * anti-aliased.
+ * @brief Whether or not the given Evas object is to be drawn anti-aliased.
  *
  * @param[in] obj The object.
  * @param[in] anti_alias @c true if the object is to be anti_aliased, @c false
@@ -529,8 +623,7 @@ EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
 EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
 
 /**
- * @brief Retrieves whether or not the given Evas object is to be drawn
- * anti_aliased.
+ * @brief Whether or not the given Evas object is to be drawn anti-aliased.
  *
  * @param[in] obj The object.
  *
@@ -543,7 +636,7 @@ EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
 EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
 
 /**
- * @brief Return a list of objects currently clipped by @c obj.
+ * @brief List of objects currently clipped by @c obj.
  *
  * This returns the internal list handle containing all objects clipped by the
  * object @c obj. If none are clipped by it, the call returns @c null. This
@@ -663,7 +756,7 @@ EOAPI unsigned int efl_canvas_object_clipped_objects_count(const Eo *obj) EINA_W
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(2);
+EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Removes the grab on @c keyname key events by @c obj.
@@ -686,10 +779,10 @@ EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Inp
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers) EINA_ARG_NONNULL(2);
+EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers);
 
 /**
- * @brief Disable all rendering on the canvas.
+ * @brief Disables all rendering on the canvas.
  *
  * This flag will be used to indicate to Evas that this object should never be
  * rendered on the canvas under any circumstances. In particular, this is
@@ -713,11 +806,19 @@ EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_
 EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
 
 /**
- * @brief Returns the state of the "no-render" flag, which means, when true,
- * that an object should never be rendered on the canvas.
+ * @brief Disables all rendering on the canvas.
  *
- * This flag can be used to avoid rendering visible clippers on the canvas,
- * even if they currently don't clip any object.
+ * This flag will be used to indicate to Evas that this object should never be
+ * rendered on the canvas under any circumstances. In particular, this is
+ * useful to avoid drawing clipper objects (or masks) even when they don't clip
+ * any object. This can also be used to replace the old source_visible flag
+ * with proxy objects.
+ *
+ * This is different to the visible property, as even visible objects marked as
+ * "no-render" will never appear on screen. But those objects can still be used
+ * as proxy sources or clippers. When hidden, all "no-render" objects will
+ * completely disappear from the canvas, and hide their clippees or be
+ * invisible when used as proxy sources.
  *
  * @param[in] obj The object.
  *
@@ -730,21 +831,17 @@ EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
 EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
 
 /**
- * @brief Returns whether the coords are logically inside the object.
+ * @brief Whether the coordinates are logically inside the object.
  *
- * When this function is called it will return a value of either @c false or
- * @c true, depending on if the coords are inside the object's current
- * geometry.
+ * A value of @c true indicates the position is logically inside the object,
+ * and @c false implies it is logically outside the object.
  *
- * A return value of @c true indicates the position is logically inside the
- * object, and @c false implies it is logically outside the object.
- *
- * If @c e is not a valid object, the return value is undefined.
+ * If @c obj is not a valid object, the return value is undefined.
  *
  * @param[in] obj The object.
- * @param[in] pos The position in pixels.
+ * @param[in] pos The coordinates in pixels.
  *
- * @return @c true if the coords are inside the object, @c false otherwise
+ * @return @c true if the coordinates are inside the object, @c false otherwise
  *
  * @since 1.22
  *
@@ -752,6 +849,21 @@ EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
  */
 EOAPI Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
 
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Returns current canvas's gesture manager
+ *
+ * @param[in] obj The object.
+ *
+ * @return The gesture manager
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI const Efl_Canvas_Gesture_Manager *efl_canvas_object_gesture_manager_get(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
+
 EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK;
 
 /** Animator tick synchronized with screen vsync if possible.
