@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Surface_Tbm;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Native Tizen Buffer Manager surface for Efl canvas
  *
  * @ingroup Efl_Canvas_Surface_Tbm
@@ -20,5 +21,6 @@ typedef Eo Efl_Canvas_Surface_Tbm;
 #define EFL_CANVAS_SURFACE_TBM_CLASS efl_canvas_surface_tbm_class_get()
 
 EWAPI const Efl_Class *efl_canvas_surface_tbm_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
