@@ -127,6 +127,7 @@
  *
  * @{
  */
+typedef Eo Evas_Textblock;
 
 /**
  * @typedef Evas_Textblock_Style
@@ -156,6 +157,14 @@ typedef struct _Efl_Text_Cursor_Cursor       Evas_Textblock_Cursor;
  */
 typedef struct _Evas_Textblock_Node_Format Evas_Object_Textblock_Node_Format;
 
+/**
+ * @typedef Evas_Textblock_Node_Format
+ * A format node.
+ *
+ * XXX: Adapter for legacy.
+ */
+typedef struct _Evas_Textblock_Node_Format Evas_Textblock_Node_Format;
+
 /**
  * @typedef Evas_Textblock_Rectangle
  * General-purpose rectangle that represents some geometry in this object.
@@ -334,7 +343,7 @@ EAPI int                                      evas_textblock_cursor_pos_get(cons
  * Go to the start of the line passed
  *
  * @param cur cursor to update.
- * @param line numer to set.
+ * @param line number to set.
  * @return @c EINA_TRUE on success, @c EINA_FALSE on error.
  */
 EAPI Eina_Bool                                evas_textblock_cursor_line_set(Evas_Textblock_Cursor *cur, int line) EINA_ARG_NONNULL(1);
@@ -595,6 +604,22 @@ EAPI Eina_Bool evas_textblock_cursor_char_prev(Evas_Textblock_Cursor *obj);
  */
 EAPI Eina_Bool evas_textblock_cursor_char_next(Evas_Textblock_Cursor *obj);
 
+/**
+ * @brief Advances the cursor one grapheme cluster backwards.
+ *
+ * @return @c true on success, @c false otherwise.
+ */
+EAPI Eina_Bool evas_textblock_cursor_cluster_prev(Evas_Textblock_Cursor *obj);
+
+/**
+ * @brief Advances the cursor one grapheme cluster forward.
+ *
+ * @return @c true on success, @c false otherwise.
+ *
+ * @ingroup Evas_Textblock_Cursor
+ */
+EAPI Eina_Bool evas_textblock_cursor_cluster_next(Evas_Textblock_Cursor *obj);
+
 /**
  * @brief Advances to the start of the next text node
  *
@@ -850,6 +875,16 @@ EAPI Evas_Textblock_Cursor *evas_object_textblock_cursor_new(const Evas_Object *
  */
 EAPI Eina_Bool evas_textblock_cursor_char_coord_set(Evas_Textblock_Cursor *obj, Evas_Coord x, Evas_Coord y);
 
+/**
+ * @brief Sets the position of the cursor according to the X and Y coordinates and
+ * grapheme clusters of text.
+ *
+ * @param[in] y y coord to set by.
+ *
+ * @return @c true on success, @c false otherwise.
+ */
+EAPI Eina_Bool evas_textblock_cursor_cluster_coord_set(Evas_Textblock_Cursor *obj, Evas_Coord x, Evas_Coord y);
+
 /**
  * Free the cursor and unassociate it from the object.
  * @note do not use it to free unassociated cursors.
@@ -1021,7 +1056,7 @@ EAPI void evas_textblock_cursor_char_delete(Evas_Textblock_Cursor *cur);
  * @ingroup Evas_Textblock
  */
 EAPI Evas_Textblock_Cursor *evas_object_textblock_cursor_get(const Evas_Object *obj);
-#include "canvas/efl_canvas_text.eo.legacy.h"
+#include "canvas/efl_canvas_text_eo.legacy.h"
 /**
  * @}
  */
