@@ -14,22 +14,15 @@ typedef Eo Efl_Canvas_Gesture_Tap;
 
 #endif
 #ifdef EFL_BETA_API_SUPPORT
-/** EFL Gesture Tap class
+/** Tap gesture class holding state information. See @ref Efl_Canvas_Gesture to
+ * see what this state is and @[Efl.Gesture.Events.gesture,tap] for a
+ * description of the Tap gesture.
  *
  * @ingroup Efl_Canvas_Gesture_Tap
  */
 #define EFL_CANVAS_GESTURE_TAP_CLASS efl_canvas_gesture_tap_class_get()
 
 EWAPI const Efl_Class *efl_canvas_gesture_tap_class_get(void);
-
-EWAPI extern const Efl_Event_Description _EFL_EVENT_GESTURE_TAP;
-
-/** Event for tap gesture
- * @return Efl_Canvas_Gesture *
- *
- * @ingroup Efl_Canvas_Gesture_Tap
- */
-#define EFL_EVENT_GESTURE_TAP (&(_EFL_EVENT_GESTURE_TAP))
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
